@@ -7,6 +7,8 @@
 
 pretty10exp <- function(x, drop.1 = FALSE, sub10 = FALSE,
                         digits = 7, digits.fuzz,
+                        ## default `off` corrects for subnormal |x| {on x86_64 ..}:;
+                        off = pmax(10^-digits, 2^-(l10x*log2(10)+1075)),
                         lab.type = c("plotmath", "latex"),
                         lab.sep = c("cdot", "times"))
 {
@@ -14,29 +16,33 @@ pretty10exp <- function(x, drop.1 = FALSE, sub10 = FALSE,
     ## ----------------------------------------------------------------------
     ## Arguments: x: numeric vector (e.g. axis tick locations)
     ## ----------------------------------------------------------------------
-    ## Author: Martin Maechler, Date: 7 May 2004; 24 Jan 2006
+    ## Author: Martin Maechler, Date: 7 May 2004, Jan 2006, ...
 
     if(!missing(digits.fuzz)) {
 	message("'digits.fuzz' is deprecated; use 'digits' instead")
 	digits <- digits.fuzz
     }
     lab.type <- match.arg(lab.type)
-    lab.sep <- match.arg(lab.sep)
+    lab.sep  <- match.arg(lab.sep)
 
-    eT <- floor(log10(abs(x)) + 10^-digits) # x == 0 case is dealt with below
+    l10x <- log10(abs(x))
+    eT <- floor(l10x + off) # x == 0 case is dealt with below
+    ##    ^^^^^ round() would be better, e.g., when  x <- 10^-(323:300)  <--> "subnormal" rounding
     mT <- signif(x / 10^eT, digits) # m[antissa]
     ss <- vector("list", length(x))
     if(sub.10 <- !isFALSE(sub10)) {
 	sub10 <- if(isTRUE(sub10))
                      c(0L,0L)
-                 else if(identical(sub10, "10"))
-                     0:1
+                 else if(identical(sub10,  "10")) c(-1L,1L)
+                 else if(identical(sub10, "100")) c(-1L,2L)
+                 else if(identical(sub10,"1000")) c(-2L,3L)
                  else
                      as.integer(sub10)
 	noE <-
 	    if(length(sub10) == 1) {
-		if(sub10 < 0)
-		    stop("'sub10' must not be negative if a single number")
+                ## *Not* really sensible -- was active till 2025-07-26 [sfsmisc version <= 1.1-21]
+		## if(sub10 < 0)
+		##     stop("'sub10' must not be negative if a single number")
 		eT <= sub10
 	    } else if(length(sub10) == 2) {
 		stopifnot(sub10[1] <= sub10[2])
